Description Usage Arguments Value
Get the public use EPF files and process them. The years allow to
specify which years should be processed. If this param is not given, all
available years, 2006 to 2018, are processed. If path is NULL,
the data is downloaded from the website of the Spanish Statistical Office,
(INE, https://www.ine.es). Alternatively, the user can provide the
path to a local copy of the data files.
1 | get_epf_data(years = NULL, path = NULL)
|
years |
a numeric vector or |
path |
path to local copies of data files |
NULL
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.